﻿//kaggle.com - strona z datasetami
using Microsoft.ML;

var context= new MLContext();

var data = context.Data.LoadFromTextFile<HousingData>("housing.csv", 
    hasHeader: true, separatorChar: ',');

var split = context.Data.TrainTestSplit(data, testFraction: 0.2);


var pipeline = context.Transforms.Text.FeaturizeText("Text", "Ocean_Proximity")
    .Append(context.Transforms.Concatenate("Pos", "Longitude", "Latitude"))
    .Append(context.Transforms.Concatenate("Rooms", "Total_Rooms", "Total_Bedrooms"))
    .Append(context.Transforms.Concatenate("Floats", "Households", "Median_Income", "Age"))
    .Append(context.Transforms.Concatenate("Features", "Pos", "Rooms", "Floats", "Text"))
    .Append(context.Regression.Trainers.LbfgsPoissonRegression());

var model = pipeline.Fit(split.TrainSet);

var predictions = model.Transform(split.TestSet);

var metrics = context.Regression.Evaluate(predictions);

Console.WriteLine($"RSquared = {metrics.RSquared}");
//-122.23,37.88,41.0,880.0,129.0,322.0,126.0,8.3252,452600.0,NEAR BAY
var newData = new HousingData
{
    Longitude = -122.23f,
    Latitude = 37.88f,
    Age = 41.0f,
    Total_Rooms = 880.0f,
    Total_Bedrooms = 129.0f,
    Population = 322.0f,
    Households = 126.0f,
    Median_Income = 8.3252f,
    Ocean_Proximity="NEAR BAY"
};
var predictionFunc = context.Model.CreatePredictionEngine<HousingData, HousingOutput>(model);

var prediction = predictionFunc.Predict(newData);

Console.WriteLine($"Prediction - {prediction.PredictedValue}");